/* eslint-disable @typescript-eslint/no-explicit-any */
import Cors from '@fastify/cors'
import RateLimit from '@fastify/rate-limit'
import { FileStore } from '@tus/file-store'
import { Server } from '@tus/server'

import { isProduction } from '@redwoodjs/api/logger'
import { createServer } from '@redwoodjs/api-server'

import { logger } from 'src/lib/logger'
import { handleTusUpload } from 'src/lib/tus'
;(async () => {
  const server = await createServer({
    logger,
    configureApiServer: async (server) => {
      await server.register(Cors, {
        origin: isProduction
          ? [process.env.ADDRESS_PROD, process.env.API_ADDRESS_PROD]
          : [process.env.ADDRESS_DEV, process.env.API_ADDRESS_DEV],
        methods: ['GET', 'POST', 'OPTIONS', 'PATCH', 'HEAD'],
        credentials: isProduction ? true : false,
      })

      await server.register(RateLimit, {
        max: Number(process.env.MAX_HTTP_CONNECTIONS_PER_MINUTE),
        timeWindow: `1 minute`,
      })
    },
  })

  const tusServer = new Server({
    path: '/files',
    respectForwardedHeaders: true,
    datastore: new FileStore({
      directory: `./files_${isProduction ? 'prod' : 'dev'}`,
    }),
    onResponseError: (_req, res, _err) => logger.error(res),
  })

  server.addContentTypeParser(
    'application/offset+octet-stream',
    (_request, _payload, done) => done(null)
  )

  server.all('/files', (req, res) =>
    handleTusUpload(req, res, tusServer, false)
  )
  server.all('/files/*', (req, res) =>
    handleTusUpload(req, res, tusServer, true)
  )

  await server.start()
})()
