import type { FindPortrait, FindPortraitVariables } from 'types/graphql'

import type {
  TypedDocumentNode,
  CellFailureProps,
  CellSuccessProps,
} from '@redwoodjs/web'

import CellEmpty from 'src/components/Cell/CellEmpty/CellEmpty'
import CellFailure from 'src/components/Cell/CellFailure/CellFailure'
import CellLoading from 'src/components/Cell/CellLoading/CellLoading'
import ContactCard from 'src/components/ContactCard/ContactCard/ContactCard'

export const QUERY: TypedDocumentNode<
  FindPortrait,
  FindPortraitVariables
> = gql`
  query ContactCardPortrait {
    portrait: portrait {
      fileId
    }
  }
`

export const Loading = () => <CellLoading />

export const Empty = () => <CellEmpty />

export const Failure = ({ error }: CellFailureProps<FindPortrait>) => (
  <CellFailure error={error} />
)

export const Success = ({
  portrait,
}: CellSuccessProps<FindPortrait, FindPortraitVariables>) => (
  <ContactCard portraitUrl={portrait.fileId} />
)
