import { useState, useEffect } from 'react'

import { mdiWeatherSunny, mdiWeatherNight } from '@mdi/js'
import Icon from '@mdi/react'

const ThemeToggle = () => {
  const [theme, setTheme] = useState(
    localStorage.getItem('theme') ? localStorage.getItem('theme') : 'light'
  )

  const handleToggle = (e: React.ChangeEvent<HTMLInputElement>) => {
    if (e.target.checked) setTheme('dark')
    else setTheme('light')
  }

  useEffect(() => {
    localStorage.setItem('theme', theme)

    document
      .querySelector('html')
      .setAttribute('data-theme', localStorage.getItem('theme'))

    document
      .querySelector('html')
      .setAttribute('data-uppy-theme', localStorage.getItem('theme'))
  }, [theme])

  return (
    // eslint-disable-next-line jsx-a11y/label-has-associated-control
    <label className="btn btn-ghost swap swap-rotate w-12">
      <input
        type="checkbox"
        className="theme-controller"
        checked={theme === 'dark'}
        onChange={handleToggle}
      />

      <Icon
        path={mdiWeatherSunny}
        className="swap-off size-8 text-yellow-500"
      />

      <Icon path={mdiWeatherNight} className="swap-on size-8 text-blue-500" />
    </label>
  )
}

export default ThemeToggle
