import { mdiMenu, mdiLogout, mdiCog } from '@mdi/js'
import Icon from '@mdi/react'

import { Link, routes } from '@redwoodjs/router'

import { useAuth } from 'src/auth'
import ThemeToggle from 'src/components/ThemeToggle/ThemeToggle'
import ToasterWrapper from 'src/components/ToasterWrapper/ToasterWrapper'

interface NavbarRoute {
  name: string
  path: string
}

type NavbarLayoutProps = {
  children?: React.ReactNode
}

const NavbarLayout = ({ children }: NavbarLayoutProps) => {
  const { isAuthenticated, logOut } = useAuth()

  const navbarRoutes: NavbarRoute[] = [
    {
      name: 'Projects',
      path: routes.projects(),
    },
    {
      name: 'Contact',
      path: routes.contact(),
    },
  ]

  const navbarAdminRoutes: NavbarRoute[] = [
    {
      name: 'Socials',
      path: routes.socials(),
    },
    {
      name: 'Projects',
      path: routes.adminProjects(),
    },
    {
      name: 'Tags',
      path: routes.tags(),
    },
    {
      name: 'Portrait',
      path: routes.portrait(),
    },
  ]

  const navbarButtons = () =>
    navbarRoutes.map((route, i) => (
      <Link key={i} to={route.path} className="btn btn-ghost btn-sm">
        {route.name}
      </Link>
    ))

  const navbarAdminButtons = () =>
    navbarAdminRoutes.map((route, i) => (
      <li key={i}>
        <Link to={route.path} className="btn btn-ghost btn-sm">
          {route.name}
        </Link>
      </li>
    ))

  return (
    <>
      <ToasterWrapper />
      <div className="sticky top-0 z-50 p-2">
        <div className="navbar rounded-xl bg-base-300 shadow-xl">
          <div className="navbar-start space-x-2 lg:first:space-x-0">
            <div className="dropdown">
              <div
                tabIndex={0}
                role="button"
                className="btn btn-square btn-ghost lg:hidden"
              >
                <Icon path={mdiMenu} className="text-base-content-100 size-8" />
              </div>
              <div
                // eslint-disable-next-line jsx-a11y/no-noninteractive-tabindex
                tabIndex={0}
                className="menu dropdown-content -ml-2 mt-4 w-36 space-y-2 rounded-box bg-base-200 shadow-xl last:space-y-0"
              >
                {navbarButtons()}
                {isAuthenticated && (
                  <div className="dropdown sm:hidden">
                    <div
                      // eslint-disable-next-line jsx-a11y/no-noninteractive-tabindex
                      tabIndex={0}
                      className="menu dropdown-content -ml-2 mt-4 w-36 space-y-2 rounded-box bg-base-200 shadow-xl"
                    >
                      <p className="btn btn-active no-animation btn-sm btn-block">
                        Admin
                      </p>

                      {navbarAdminButtons()}
                      <li>
                        <button
                          onClick={logOut}
                          className="btn btn-ghost btn-sm"
                        >
                          Logout
                        </button>
                      </li>
                    </div>
                  </div>
                )}
              </div>
            </div>
            <Link
              to={routes.home()}
              className="btn btn-ghost hidden font-syne text-xl sm:flex"
            >
              {process.env.FIRST_NAME + ' ' + process.env.LAST_NAME}
            </Link>
          </div>
          <div className="navbar-center">
            <Link
              to={routes.home()}
              className="btn btn-ghost font-syne text-xl sm:hidden"
            >
              {process.env.FIRST_NAME + ' ' + process.env.LAST_NAME}
            </Link>
          </div>
          <div className="navbar-center hidden lg:flex">
            <div className="space-x-2 font-syne">{navbarButtons()}</div>
          </div>
          <div className="navbar-end space-x-2">
            {isAuthenticated && (
              <div className="hidden space-x-2 sm:flex">
                <button className="btn btn-square btn-ghost" onClick={logOut}>
                  <Icon path={mdiLogout} className="size-8" />
                </button>
                <div className="dropdown">
                  <div
                    tabIndex={0}
                    role="button"
                    className="btn btn-square btn-ghost"
                  >
                    <Icon path={mdiCog} className="size-8" />
                  </div>
                  <ul
                    // eslint-disable-next-line jsx-a11y/no-noninteractive-tabindex
                    tabIndex={0}
                    className="menu dropdown-content -ml-8 mt-4 w-36 space-y-2 rounded-box bg-base-200 shadow-xl"
                  >
                    {navbarAdminButtons()}
                  </ul>
                </div>
              </div>
            )}
            <ThemeToggle />
          </div>
        </div>
      </div>
      <div className="p-2 font-inter">
        <main>{children}</main>
      </div>
    </>
  )
}

export default NavbarLayout
